# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from importlib import import_module
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe.params.v2.core import accounts as accounts, vault as vault
    from stripe.params.v2.core._account_close_params import (
        AccountCloseParams as AccountCloseParams,
    )
    from stripe.params.v2.core._account_create_params import (
        AccountCreateParams as AccountCreateParams,
        AccountCreateParamsConfiguration as AccountCreateParamsConfiguration,
        AccountCreateParamsConfigurationCardCreator as AccountCreateParamsConfigurationCardCreator,
        AccountCreateParamsConfigurationCardCreatorCapabilities as AccountCreateParamsConfigurationCardCreatorCapabilities,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercial as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercial,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCeltic as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCeltic,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticChargeCard as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticChargeCard,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticSpendCard as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticSpendCard,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBank as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBank,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankChargeCard as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankChargeCard,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankSpendCard as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankSpendCard,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialLead as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialLead,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialLeadPrepaidCard as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialLeadPrepaidCard,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripe as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripe,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripeChargeCard as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripeChargeCard,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripePrepaidCard as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripePrepaidCard,
        AccountCreateParamsConfigurationCustomer as AccountCreateParamsConfigurationCustomer,
        AccountCreateParamsConfigurationCustomerAutomaticIndirectTax as AccountCreateParamsConfigurationCustomerAutomaticIndirectTax,
        AccountCreateParamsConfigurationCustomerBilling as AccountCreateParamsConfigurationCustomerBilling,
        AccountCreateParamsConfigurationCustomerBillingInvoice as AccountCreateParamsConfigurationCustomerBillingInvoice,
        AccountCreateParamsConfigurationCustomerBillingInvoiceCustomField as AccountCreateParamsConfigurationCustomerBillingInvoiceCustomField,
        AccountCreateParamsConfigurationCustomerBillingInvoiceRendering as AccountCreateParamsConfigurationCustomerBillingInvoiceRendering,
        AccountCreateParamsConfigurationCustomerCapabilities as AccountCreateParamsConfigurationCustomerCapabilities,
        AccountCreateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTax as AccountCreateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTax,
        AccountCreateParamsConfigurationCustomerShipping as AccountCreateParamsConfigurationCustomerShipping,
        AccountCreateParamsConfigurationCustomerShippingAddress as AccountCreateParamsConfigurationCustomerShippingAddress,
        AccountCreateParamsConfigurationMerchant as AccountCreateParamsConfigurationMerchant,
        AccountCreateParamsConfigurationMerchantBacsDebitPayments as AccountCreateParamsConfigurationMerchantBacsDebitPayments,
        AccountCreateParamsConfigurationMerchantBranding as AccountCreateParamsConfigurationMerchantBranding,
        AccountCreateParamsConfigurationMerchantCapabilities as AccountCreateParamsConfigurationMerchantCapabilities,
        AccountCreateParamsConfigurationMerchantCapabilitiesAchDebitPayments as AccountCreateParamsConfigurationMerchantCapabilitiesAchDebitPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesAcssDebitPayments as AccountCreateParamsConfigurationMerchantCapabilitiesAcssDebitPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesAffirmPayments as AccountCreateParamsConfigurationMerchantCapabilitiesAffirmPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesAlmaPayments as AccountCreateParamsConfigurationMerchantCapabilitiesAlmaPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesAmazonPayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesAmazonPayPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesAuBecsDebitPayments as AccountCreateParamsConfigurationMerchantCapabilitiesAuBecsDebitPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesBacsDebitPayments as AccountCreateParamsConfigurationMerchantCapabilitiesBacsDebitPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesBancontactPayments as AccountCreateParamsConfigurationMerchantCapabilitiesBancontactPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesBlikPayments as AccountCreateParamsConfigurationMerchantCapabilitiesBlikPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesBoletoPayments as AccountCreateParamsConfigurationMerchantCapabilitiesBoletoPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesCardPayments as AccountCreateParamsConfigurationMerchantCapabilitiesCardPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesCartesBancairesPayments as AccountCreateParamsConfigurationMerchantCapabilitiesCartesBancairesPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesCashappPayments as AccountCreateParamsConfigurationMerchantCapabilitiesCashappPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesEpsPayments as AccountCreateParamsConfigurationMerchantCapabilitiesEpsPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesFpxPayments as AccountCreateParamsConfigurationMerchantCapabilitiesFpxPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesGbBankTransferPayments as AccountCreateParamsConfigurationMerchantCapabilitiesGbBankTransferPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesGrabpayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesGrabpayPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesIdealPayments as AccountCreateParamsConfigurationMerchantCapabilitiesIdealPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesJcbPayments as AccountCreateParamsConfigurationMerchantCapabilitiesJcbPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesJpBankTransferPayments as AccountCreateParamsConfigurationMerchantCapabilitiesJpBankTransferPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesKakaoPayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesKakaoPayPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesKlarnaPayments as AccountCreateParamsConfigurationMerchantCapabilitiesKlarnaPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesKonbiniPayments as AccountCreateParamsConfigurationMerchantCapabilitiesKonbiniPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesKrCardPayments as AccountCreateParamsConfigurationMerchantCapabilitiesKrCardPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesLinkPayments as AccountCreateParamsConfigurationMerchantCapabilitiesLinkPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesMobilepayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesMobilepayPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesMultibancoPayments as AccountCreateParamsConfigurationMerchantCapabilitiesMultibancoPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesMxBankTransferPayments as AccountCreateParamsConfigurationMerchantCapabilitiesMxBankTransferPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesNaverPayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesNaverPayPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesOxxoPayments as AccountCreateParamsConfigurationMerchantCapabilitiesOxxoPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesP24Payments as AccountCreateParamsConfigurationMerchantCapabilitiesP24Payments,
        AccountCreateParamsConfigurationMerchantCapabilitiesPayByBankPayments as AccountCreateParamsConfigurationMerchantCapabilitiesPayByBankPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesPaycoPayments as AccountCreateParamsConfigurationMerchantCapabilitiesPaycoPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesPaynowPayments as AccountCreateParamsConfigurationMerchantCapabilitiesPaynowPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesPromptpayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesPromptpayPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesRevolutPayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesRevolutPayPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesSamsungPayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesSamsungPayPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesSepaBankTransferPayments as AccountCreateParamsConfigurationMerchantCapabilitiesSepaBankTransferPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesSepaDebitPayments as AccountCreateParamsConfigurationMerchantCapabilitiesSepaDebitPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesSwishPayments as AccountCreateParamsConfigurationMerchantCapabilitiesSwishPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesTwintPayments as AccountCreateParamsConfigurationMerchantCapabilitiesTwintPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesUsBankTransferPayments as AccountCreateParamsConfigurationMerchantCapabilitiesUsBankTransferPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesZipPayments as AccountCreateParamsConfigurationMerchantCapabilitiesZipPayments,
        AccountCreateParamsConfigurationMerchantCardPayments as AccountCreateParamsConfigurationMerchantCardPayments,
        AccountCreateParamsConfigurationMerchantCardPaymentsDeclineOn as AccountCreateParamsConfigurationMerchantCardPaymentsDeclineOn,
        AccountCreateParamsConfigurationMerchantStatementDescriptor as AccountCreateParamsConfigurationMerchantStatementDescriptor,
        AccountCreateParamsConfigurationMerchantSupport as AccountCreateParamsConfigurationMerchantSupport,
        AccountCreateParamsConfigurationMerchantSupportAddress as AccountCreateParamsConfigurationMerchantSupportAddress,
        AccountCreateParamsConfigurationRecipient as AccountCreateParamsConfigurationRecipient,
        AccountCreateParamsConfigurationRecipientCapabilities as AccountCreateParamsConfigurationRecipientCapabilities,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccounts as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccounts,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsLocal as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsLocal,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsWire as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsWire,
        AccountCreateParamsConfigurationRecipientCapabilitiesCards as AccountCreateParamsConfigurationRecipientCapabilitiesCards,
        AccountCreateParamsConfigurationRecipientCapabilitiesCryptoWallets as AccountCreateParamsConfigurationRecipientCapabilitiesCryptoWallets,
        AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalance as AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalance,
        AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfers as AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfers,
        AccountCreateParamsConfigurationStorer as AccountCreateParamsConfigurationStorer,
        AccountCreateParamsConfigurationStorerCapabilities as AccountCreateParamsConfigurationStorerCapabilities,
        AccountCreateParamsConfigurationStorerCapabilitiesFinancialAddresses as AccountCreateParamsConfigurationStorerCapabilitiesFinancialAddresses,
        AccountCreateParamsConfigurationStorerCapabilitiesFinancialAddressesBankAccounts as AccountCreateParamsConfigurationStorerCapabilitiesFinancialAddressesBankAccounts,
        AccountCreateParamsConfigurationStorerCapabilitiesFinancialAddressesCryptoWallets as AccountCreateParamsConfigurationStorerCapabilitiesFinancialAddressesCryptoWallets,
        AccountCreateParamsConfigurationStorerCapabilitiesHoldsCurrencies as AccountCreateParamsConfigurationStorerCapabilitiesHoldsCurrencies,
        AccountCreateParamsConfigurationStorerCapabilitiesHoldsCurrenciesGbp as AccountCreateParamsConfigurationStorerCapabilitiesHoldsCurrenciesGbp,
        AccountCreateParamsConfigurationStorerCapabilitiesHoldsCurrenciesUsd as AccountCreateParamsConfigurationStorerCapabilitiesHoldsCurrenciesUsd,
        AccountCreateParamsConfigurationStorerCapabilitiesHoldsCurrenciesUsdc as AccountCreateParamsConfigurationStorerCapabilitiesHoldsCurrenciesUsdc,
        AccountCreateParamsConfigurationStorerCapabilitiesInboundTransfers as AccountCreateParamsConfigurationStorerCapabilitiesInboundTransfers,
        AccountCreateParamsConfigurationStorerCapabilitiesInboundTransfersBankAccounts as AccountCreateParamsConfigurationStorerCapabilitiesInboundTransfersBankAccounts,
        AccountCreateParamsConfigurationStorerCapabilitiesOutboundPayments as AccountCreateParamsConfigurationStorerCapabilitiesOutboundPayments,
        AccountCreateParamsConfigurationStorerCapabilitiesOutboundPaymentsBankAccounts as AccountCreateParamsConfigurationStorerCapabilitiesOutboundPaymentsBankAccounts,
        AccountCreateParamsConfigurationStorerCapabilitiesOutboundPaymentsCards as AccountCreateParamsConfigurationStorerCapabilitiesOutboundPaymentsCards,
        AccountCreateParamsConfigurationStorerCapabilitiesOutboundPaymentsCryptoWallets as AccountCreateParamsConfigurationStorerCapabilitiesOutboundPaymentsCryptoWallets,
        AccountCreateParamsConfigurationStorerCapabilitiesOutboundPaymentsFinancialAccounts as AccountCreateParamsConfigurationStorerCapabilitiesOutboundPaymentsFinancialAccounts,
        AccountCreateParamsConfigurationStorerCapabilitiesOutboundTransfers as AccountCreateParamsConfigurationStorerCapabilitiesOutboundTransfers,
        AccountCreateParamsConfigurationStorerCapabilitiesOutboundTransfersBankAccounts as AccountCreateParamsConfigurationStorerCapabilitiesOutboundTransfersBankAccounts,
        AccountCreateParamsConfigurationStorerCapabilitiesOutboundTransfersCryptoWallets as AccountCreateParamsConfigurationStorerCapabilitiesOutboundTransfersCryptoWallets,
        AccountCreateParamsConfigurationStorerCapabilitiesOutboundTransfersFinancialAccounts as AccountCreateParamsConfigurationStorerCapabilitiesOutboundTransfersFinancialAccounts,
        AccountCreateParamsConfigurationStorerRegulatedActivity as AccountCreateParamsConfigurationStorerRegulatedActivity,
        AccountCreateParamsDefaults as AccountCreateParamsDefaults,
        AccountCreateParamsDefaultsProfile as AccountCreateParamsDefaultsProfile,
        AccountCreateParamsDefaultsResponsibilities as AccountCreateParamsDefaultsResponsibilities,
        AccountCreateParamsIdentity as AccountCreateParamsIdentity,
        AccountCreateParamsIdentityAttestations as AccountCreateParamsIdentityAttestations,
        AccountCreateParamsIdentityAttestationsDirectorshipDeclaration as AccountCreateParamsIdentityAttestationsDirectorshipDeclaration,
        AccountCreateParamsIdentityAttestationsOwnershipDeclaration as AccountCreateParamsIdentityAttestationsOwnershipDeclaration,
        AccountCreateParamsIdentityAttestationsPersonsProvided as AccountCreateParamsIdentityAttestationsPersonsProvided,
        AccountCreateParamsIdentityAttestationsRepresentativeDeclaration as AccountCreateParamsIdentityAttestationsRepresentativeDeclaration,
        AccountCreateParamsIdentityAttestationsTermsOfService as AccountCreateParamsIdentityAttestationsTermsOfService,
        AccountCreateParamsIdentityAttestationsTermsOfServiceAccount as AccountCreateParamsIdentityAttestationsTermsOfServiceAccount,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreator as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreator,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercial as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercial,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialAccountHolder as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialAccountHolder,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCeltic as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCeltic,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticApplePay as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticApplePay,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCard as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCard,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardBankTerms as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardBankTerms,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardPlatform as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardPlatform,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCard as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCard,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardBankTerms as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardBankTerms,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardFinancingDisclosures as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardFinancingDisclosures,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardPlatform as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardPlatform,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBank as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBank,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankApplePay as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankApplePay,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCard as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCard,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardBankTerms as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardBankTerms,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardFinancingDisclosures as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardFinancingDisclosures,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardPlatform as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardPlatform,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCard as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCard,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardBankTerms as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardBankTerms,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardFinancingDisclosures as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardFinancingDisclosures,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialGlobalAccountHolder as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialGlobalAccountHolder,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLead as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLead,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadApplePay as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadApplePay,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCard as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCard,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCardBankTerms as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCardBankTerms,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCardPlatform as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCardPlatform,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCryptoStorer as AccountCreateParamsIdentityAttestationsTermsOfServiceCryptoStorer,
        AccountCreateParamsIdentityAttestationsTermsOfServiceStorer as AccountCreateParamsIdentityAttestationsTermsOfServiceStorer,
        AccountCreateParamsIdentityBusinessDetails as AccountCreateParamsIdentityBusinessDetails,
        AccountCreateParamsIdentityBusinessDetailsAddress as AccountCreateParamsIdentityBusinessDetailsAddress,
        AccountCreateParamsIdentityBusinessDetailsAnnualRevenue as AccountCreateParamsIdentityBusinessDetailsAnnualRevenue,
        AccountCreateParamsIdentityBusinessDetailsDocuments as AccountCreateParamsIdentityBusinessDetailsDocuments,
        AccountCreateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification as AccountCreateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification,
        AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyLicense as AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyLicense,
        AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation as AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation,
        AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree as AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree,
        AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification as AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification,
        AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification as AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification,
        AccountCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerification as AccountCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerification,
        AccountCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack as AccountCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack,
        AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfAddress as AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfAddress,
        AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistration as AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistration,
        AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership as AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership,
        AccountCreateParamsIdentityBusinessDetailsIdNumber as AccountCreateParamsIdentityBusinessDetailsIdNumber,
        AccountCreateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue as AccountCreateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue,
        AccountCreateParamsIdentityBusinessDetailsScriptAddresses as AccountCreateParamsIdentityBusinessDetailsScriptAddresses,
        AccountCreateParamsIdentityBusinessDetailsScriptAddressesKana as AccountCreateParamsIdentityBusinessDetailsScriptAddressesKana,
        AccountCreateParamsIdentityBusinessDetailsScriptAddressesKanji as AccountCreateParamsIdentityBusinessDetailsScriptAddressesKanji,
        AccountCreateParamsIdentityBusinessDetailsScriptNames as AccountCreateParamsIdentityBusinessDetailsScriptNames,
        AccountCreateParamsIdentityBusinessDetailsScriptNamesKana as AccountCreateParamsIdentityBusinessDetailsScriptNamesKana,
        AccountCreateParamsIdentityBusinessDetailsScriptNamesKanji as AccountCreateParamsIdentityBusinessDetailsScriptNamesKanji,
        AccountCreateParamsIdentityIndividual as AccountCreateParamsIdentityIndividual,
        AccountCreateParamsIdentityIndividualAdditionalAddress as AccountCreateParamsIdentityIndividualAdditionalAddress,
        AccountCreateParamsIdentityIndividualAdditionalName as AccountCreateParamsIdentityIndividualAdditionalName,
        AccountCreateParamsIdentityIndividualAddress as AccountCreateParamsIdentityIndividualAddress,
        AccountCreateParamsIdentityIndividualDateOfBirth as AccountCreateParamsIdentityIndividualDateOfBirth,
        AccountCreateParamsIdentityIndividualDocuments as AccountCreateParamsIdentityIndividualDocuments,
        AccountCreateParamsIdentityIndividualDocumentsCompanyAuthorization as AccountCreateParamsIdentityIndividualDocumentsCompanyAuthorization,
        AccountCreateParamsIdentityIndividualDocumentsPassport as AccountCreateParamsIdentityIndividualDocumentsPassport,
        AccountCreateParamsIdentityIndividualDocumentsPrimaryVerification as AccountCreateParamsIdentityIndividualDocumentsPrimaryVerification,
        AccountCreateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack as AccountCreateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack,
        AccountCreateParamsIdentityIndividualDocumentsSecondaryVerification as AccountCreateParamsIdentityIndividualDocumentsSecondaryVerification,
        AccountCreateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack as AccountCreateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack,
        AccountCreateParamsIdentityIndividualDocumentsVisa as AccountCreateParamsIdentityIndividualDocumentsVisa,
        AccountCreateParamsIdentityIndividualIdNumber as AccountCreateParamsIdentityIndividualIdNumber,
        AccountCreateParamsIdentityIndividualRelationship as AccountCreateParamsIdentityIndividualRelationship,
        AccountCreateParamsIdentityIndividualScriptAddresses as AccountCreateParamsIdentityIndividualScriptAddresses,
        AccountCreateParamsIdentityIndividualScriptAddressesKana as AccountCreateParamsIdentityIndividualScriptAddressesKana,
        AccountCreateParamsIdentityIndividualScriptAddressesKanji as AccountCreateParamsIdentityIndividualScriptAddressesKanji,
        AccountCreateParamsIdentityIndividualScriptNames as AccountCreateParamsIdentityIndividualScriptNames,
        AccountCreateParamsIdentityIndividualScriptNamesKana as AccountCreateParamsIdentityIndividualScriptNamesKana,
        AccountCreateParamsIdentityIndividualScriptNamesKanji as AccountCreateParamsIdentityIndividualScriptNamesKanji,
    )
    from stripe.params.v2.core._account_link_create_params import (
        AccountLinkCreateParams as AccountLinkCreateParams,
        AccountLinkCreateParamsUseCase as AccountLinkCreateParamsUseCase,
        AccountLinkCreateParamsUseCaseAccountOnboarding as AccountLinkCreateParamsUseCaseAccountOnboarding,
        AccountLinkCreateParamsUseCaseAccountOnboardingCollectionOptions as AccountLinkCreateParamsUseCaseAccountOnboardingCollectionOptions,
        AccountLinkCreateParamsUseCaseAccountUpdate as AccountLinkCreateParamsUseCaseAccountUpdate,
        AccountLinkCreateParamsUseCaseAccountUpdateCollectionOptions as AccountLinkCreateParamsUseCaseAccountUpdateCollectionOptions,
    )
    from stripe.params.v2.core._account_list_params import (
        AccountListParams as AccountListParams,
    )
    from stripe.params.v2.core._account_retrieve_params import (
        AccountRetrieveParams as AccountRetrieveParams,
    )
    from stripe.params.v2.core._account_update_params import (
        AccountUpdateParams as AccountUpdateParams,
        AccountUpdateParamsConfiguration as AccountUpdateParamsConfiguration,
        AccountUpdateParamsConfigurationCardCreator as AccountUpdateParamsConfigurationCardCreator,
        AccountUpdateParamsConfigurationCardCreatorCapabilities as AccountUpdateParamsConfigurationCardCreatorCapabilities,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercial as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercial,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCeltic as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCeltic,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCelticChargeCard as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCelticChargeCard,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCelticSpendCard as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCelticSpendCard,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBank as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBank,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankChargeCard as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankChargeCard,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankSpendCard as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankSpendCard,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialLead as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialLead,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialLeadPrepaidCard as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialLeadPrepaidCard,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialStripe as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialStripe,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialStripeChargeCard as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialStripeChargeCard,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialStripePrepaidCard as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialStripePrepaidCard,
        AccountUpdateParamsConfigurationCustomer as AccountUpdateParamsConfigurationCustomer,
        AccountUpdateParamsConfigurationCustomerAutomaticIndirectTax as AccountUpdateParamsConfigurationCustomerAutomaticIndirectTax,
        AccountUpdateParamsConfigurationCustomerBilling as AccountUpdateParamsConfigurationCustomerBilling,
        AccountUpdateParamsConfigurationCustomerBillingInvoice as AccountUpdateParamsConfigurationCustomerBillingInvoice,
        AccountUpdateParamsConfigurationCustomerBillingInvoiceCustomField as AccountUpdateParamsConfigurationCustomerBillingInvoiceCustomField,
        AccountUpdateParamsConfigurationCustomerBillingInvoiceRendering as AccountUpdateParamsConfigurationCustomerBillingInvoiceRendering,
        AccountUpdateParamsConfigurationCustomerCapabilities as AccountUpdateParamsConfigurationCustomerCapabilities,
        AccountUpdateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTax as AccountUpdateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTax,
        AccountUpdateParamsConfigurationCustomerShipping as AccountUpdateParamsConfigurationCustomerShipping,
        AccountUpdateParamsConfigurationCustomerShippingAddress as AccountUpdateParamsConfigurationCustomerShippingAddress,
        AccountUpdateParamsConfigurationMerchant as AccountUpdateParamsConfigurationMerchant,
        AccountUpdateParamsConfigurationMerchantBacsDebitPayments as AccountUpdateParamsConfigurationMerchantBacsDebitPayments,
        AccountUpdateParamsConfigurationMerchantBranding as AccountUpdateParamsConfigurationMerchantBranding,
        AccountUpdateParamsConfigurationMerchantCapabilities as AccountUpdateParamsConfigurationMerchantCapabilities,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAchDebitPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesAchDebitPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAcssDebitPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesAcssDebitPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAffirmPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesAffirmPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAlmaPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesAlmaPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAmazonPayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesAmazonPayPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAuBecsDebitPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesAuBecsDebitPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesBacsDebitPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesBacsDebitPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesBancontactPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesBancontactPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesBlikPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesBlikPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesBoletoPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesBoletoPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesCardPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesCardPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesCartesBancairesPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesCartesBancairesPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesCashappPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesCashappPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesEpsPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesEpsPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesFpxPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesFpxPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesGbBankTransferPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesGbBankTransferPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesGrabpayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesGrabpayPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesIdealPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesIdealPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesJcbPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesJcbPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesJpBankTransferPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesJpBankTransferPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesKakaoPayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesKakaoPayPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesKlarnaPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesKlarnaPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesKonbiniPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesKonbiniPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesKrCardPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesKrCardPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesLinkPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesLinkPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesMobilepayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesMobilepayPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesMultibancoPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesMultibancoPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesMxBankTransferPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesMxBankTransferPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesNaverPayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesNaverPayPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesOxxoPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesOxxoPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesP24Payments as AccountUpdateParamsConfigurationMerchantCapabilitiesP24Payments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesPayByBankPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesPayByBankPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesPaycoPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesPaycoPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesPaynowPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesPaynowPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesPromptpayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesPromptpayPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesRevolutPayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesRevolutPayPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesSamsungPayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesSamsungPayPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesSepaBankTransferPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesSepaBankTransferPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesSepaDebitPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesSepaDebitPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesSwishPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesSwishPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesTwintPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesTwintPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesUsBankTransferPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesUsBankTransferPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesZipPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesZipPayments,
        AccountUpdateParamsConfigurationMerchantCardPayments as AccountUpdateParamsConfigurationMerchantCardPayments,
        AccountUpdateParamsConfigurationMerchantCardPaymentsDeclineOn as AccountUpdateParamsConfigurationMerchantCardPaymentsDeclineOn,
        AccountUpdateParamsConfigurationMerchantStatementDescriptor as AccountUpdateParamsConfigurationMerchantStatementDescriptor,
        AccountUpdateParamsConfigurationMerchantSupport as AccountUpdateParamsConfigurationMerchantSupport,
        AccountUpdateParamsConfigurationMerchantSupportAddress as AccountUpdateParamsConfigurationMerchantSupportAddress,
        AccountUpdateParamsConfigurationRecipient as AccountUpdateParamsConfigurationRecipient,
        AccountUpdateParamsConfigurationRecipientCapabilities as AccountUpdateParamsConfigurationRecipientCapabilities,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccounts as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccounts,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsLocal as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsLocal,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsWire as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsWire,
        AccountUpdateParamsConfigurationRecipientCapabilitiesCards as AccountUpdateParamsConfigurationRecipientCapabilitiesCards,
        AccountUpdateParamsConfigurationRecipientCapabilitiesCryptoWallets as AccountUpdateParamsConfigurationRecipientCapabilitiesCryptoWallets,
        AccountUpdateParamsConfigurationRecipientCapabilitiesStripeBalance as AccountUpdateParamsConfigurationRecipientCapabilitiesStripeBalance,
        AccountUpdateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfers as AccountUpdateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfers,
        AccountUpdateParamsConfigurationStorer as AccountUpdateParamsConfigurationStorer,
        AccountUpdateParamsConfigurationStorerCapabilities as AccountUpdateParamsConfigurationStorerCapabilities,
        AccountUpdateParamsConfigurationStorerCapabilitiesFinancialAddresses as AccountUpdateParamsConfigurationStorerCapabilitiesFinancialAddresses,
        AccountUpdateParamsConfigurationStorerCapabilitiesFinancialAddressesBankAccounts as AccountUpdateParamsConfigurationStorerCapabilitiesFinancialAddressesBankAccounts,
        AccountUpdateParamsConfigurationStorerCapabilitiesFinancialAddressesCryptoWallets as AccountUpdateParamsConfigurationStorerCapabilitiesFinancialAddressesCryptoWallets,
        AccountUpdateParamsConfigurationStorerCapabilitiesHoldsCurrencies as AccountUpdateParamsConfigurationStorerCapabilitiesHoldsCurrencies,
        AccountUpdateParamsConfigurationStorerCapabilitiesHoldsCurrenciesGbp as AccountUpdateParamsConfigurationStorerCapabilitiesHoldsCurrenciesGbp,
        AccountUpdateParamsConfigurationStorerCapabilitiesHoldsCurrenciesUsd as AccountUpdateParamsConfigurationStorerCapabilitiesHoldsCurrenciesUsd,
        AccountUpdateParamsConfigurationStorerCapabilitiesHoldsCurrenciesUsdc as AccountUpdateParamsConfigurationStorerCapabilitiesHoldsCurrenciesUsdc,
        AccountUpdateParamsConfigurationStorerCapabilitiesInboundTransfers as AccountUpdateParamsConfigurationStorerCapabilitiesInboundTransfers,
        AccountUpdateParamsConfigurationStorerCapabilitiesInboundTransfersBankAccounts as AccountUpdateParamsConfigurationStorerCapabilitiesInboundTransfersBankAccounts,
        AccountUpdateParamsConfigurationStorerCapabilitiesOutboundPayments as AccountUpdateParamsConfigurationStorerCapabilitiesOutboundPayments,
        AccountUpdateParamsConfigurationStorerCapabilitiesOutboundPaymentsBankAccounts as AccountUpdateParamsConfigurationStorerCapabilitiesOutboundPaymentsBankAccounts,
        AccountUpdateParamsConfigurationStorerCapabilitiesOutboundPaymentsCards as AccountUpdateParamsConfigurationStorerCapabilitiesOutboundPaymentsCards,
        AccountUpdateParamsConfigurationStorerCapabilitiesOutboundPaymentsCryptoWallets as AccountUpdateParamsConfigurationStorerCapabilitiesOutboundPaymentsCryptoWallets,
        AccountUpdateParamsConfigurationStorerCapabilitiesOutboundPaymentsFinancialAccounts as AccountUpdateParamsConfigurationStorerCapabilitiesOutboundPaymentsFinancialAccounts,
        AccountUpdateParamsConfigurationStorerCapabilitiesOutboundTransfers as AccountUpdateParamsConfigurationStorerCapabilitiesOutboundTransfers,
        AccountUpdateParamsConfigurationStorerCapabilitiesOutboundTransfersBankAccounts as AccountUpdateParamsConfigurationStorerCapabilitiesOutboundTransfersBankAccounts,
        AccountUpdateParamsConfigurationStorerCapabilitiesOutboundTransfersCryptoWallets as AccountUpdateParamsConfigurationStorerCapabilitiesOutboundTransfersCryptoWallets,
        AccountUpdateParamsConfigurationStorerCapabilitiesOutboundTransfersFinancialAccounts as AccountUpdateParamsConfigurationStorerCapabilitiesOutboundTransfersFinancialAccounts,
        AccountUpdateParamsConfigurationStorerRegulatedActivity as AccountUpdateParamsConfigurationStorerRegulatedActivity,
        AccountUpdateParamsDefaults as AccountUpdateParamsDefaults,
        AccountUpdateParamsDefaultsProfile as AccountUpdateParamsDefaultsProfile,
        AccountUpdateParamsDefaultsResponsibilities as AccountUpdateParamsDefaultsResponsibilities,
        AccountUpdateParamsIdentity as AccountUpdateParamsIdentity,
        AccountUpdateParamsIdentityAttestations as AccountUpdateParamsIdentityAttestations,
        AccountUpdateParamsIdentityAttestationsDirectorshipDeclaration as AccountUpdateParamsIdentityAttestationsDirectorshipDeclaration,
        AccountUpdateParamsIdentityAttestationsOwnershipDeclaration as AccountUpdateParamsIdentityAttestationsOwnershipDeclaration,
        AccountUpdateParamsIdentityAttestationsPersonsProvided as AccountUpdateParamsIdentityAttestationsPersonsProvided,
        AccountUpdateParamsIdentityAttestationsRepresentativeDeclaration as AccountUpdateParamsIdentityAttestationsRepresentativeDeclaration,
        AccountUpdateParamsIdentityAttestationsTermsOfService as AccountUpdateParamsIdentityAttestationsTermsOfService,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceAccount as AccountUpdateParamsIdentityAttestationsTermsOfServiceAccount,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreator as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreator,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercial as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercial,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialAccountHolder as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialAccountHolder,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCeltic as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCeltic,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticApplePay as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticApplePay,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCard as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCard,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardBankTerms as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardBankTerms,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardPlatform as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardPlatform,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCard as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCard,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardBankTerms as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardBankTerms,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardFinancingDisclosures as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardFinancingDisclosures,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardPlatform as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardPlatform,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBank as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBank,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankApplePay as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankApplePay,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCard as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCard,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardBankTerms as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardBankTerms,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardFinancingDisclosures as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardFinancingDisclosures,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardPlatform as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardPlatform,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCard as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCard,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardBankTerms as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardBankTerms,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardFinancingDisclosures as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardFinancingDisclosures,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialGlobalAccountHolder as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialGlobalAccountHolder,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLead as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLead,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadApplePay as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadApplePay,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCard as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCard,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCardBankTerms as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCardBankTerms,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCardPlatform as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCardPlatform,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCryptoStorer as AccountUpdateParamsIdentityAttestationsTermsOfServiceCryptoStorer,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceStorer as AccountUpdateParamsIdentityAttestationsTermsOfServiceStorer,
        AccountUpdateParamsIdentityBusinessDetails as AccountUpdateParamsIdentityBusinessDetails,
        AccountUpdateParamsIdentityBusinessDetailsAddress as AccountUpdateParamsIdentityBusinessDetailsAddress,
        AccountUpdateParamsIdentityBusinessDetailsAnnualRevenue as AccountUpdateParamsIdentityBusinessDetailsAnnualRevenue,
        AccountUpdateParamsIdentityBusinessDetailsDocuments as AccountUpdateParamsIdentityBusinessDetailsDocuments,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification as AccountUpdateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyLicense as AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyLicense,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation as AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree as AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification as AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification as AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsPrimaryVerification as AccountUpdateParamsIdentityBusinessDetailsDocumentsPrimaryVerification,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack as AccountUpdateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfAddress as AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfAddress,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfRegistration as AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfRegistration,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership as AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership,
        AccountUpdateParamsIdentityBusinessDetailsIdNumber as AccountUpdateParamsIdentityBusinessDetailsIdNumber,
        AccountUpdateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue as AccountUpdateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue,
        AccountUpdateParamsIdentityBusinessDetailsScriptAddresses as AccountUpdateParamsIdentityBusinessDetailsScriptAddresses,
        AccountUpdateParamsIdentityBusinessDetailsScriptAddressesKana as AccountUpdateParamsIdentityBusinessDetailsScriptAddressesKana,
        AccountUpdateParamsIdentityBusinessDetailsScriptAddressesKanji as AccountUpdateParamsIdentityBusinessDetailsScriptAddressesKanji,
        AccountUpdateParamsIdentityBusinessDetailsScriptNames as AccountUpdateParamsIdentityBusinessDetailsScriptNames,
        AccountUpdateParamsIdentityBusinessDetailsScriptNamesKana as AccountUpdateParamsIdentityBusinessDetailsScriptNamesKana,
        AccountUpdateParamsIdentityBusinessDetailsScriptNamesKanji as AccountUpdateParamsIdentityBusinessDetailsScriptNamesKanji,
        AccountUpdateParamsIdentityIndividual as AccountUpdateParamsIdentityIndividual,
        AccountUpdateParamsIdentityIndividualAdditionalAddress as AccountUpdateParamsIdentityIndividualAdditionalAddress,
        AccountUpdateParamsIdentityIndividualAdditionalName as AccountUpdateParamsIdentityIndividualAdditionalName,
        AccountUpdateParamsIdentityIndividualAddress as AccountUpdateParamsIdentityIndividualAddress,
        AccountUpdateParamsIdentityIndividualDateOfBirth as AccountUpdateParamsIdentityIndividualDateOfBirth,
        AccountUpdateParamsIdentityIndividualDocuments as AccountUpdateParamsIdentityIndividualDocuments,
        AccountUpdateParamsIdentityIndividualDocumentsCompanyAuthorization as AccountUpdateParamsIdentityIndividualDocumentsCompanyAuthorization,
        AccountUpdateParamsIdentityIndividualDocumentsPassport as AccountUpdateParamsIdentityIndividualDocumentsPassport,
        AccountUpdateParamsIdentityIndividualDocumentsPrimaryVerification as AccountUpdateParamsIdentityIndividualDocumentsPrimaryVerification,
        AccountUpdateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack as AccountUpdateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack,
        AccountUpdateParamsIdentityIndividualDocumentsSecondaryVerification as AccountUpdateParamsIdentityIndividualDocumentsSecondaryVerification,
        AccountUpdateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack as AccountUpdateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack,
        AccountUpdateParamsIdentityIndividualDocumentsVisa as AccountUpdateParamsIdentityIndividualDocumentsVisa,
        AccountUpdateParamsIdentityIndividualIdNumber as AccountUpdateParamsIdentityIndividualIdNumber,
        AccountUpdateParamsIdentityIndividualRelationship as AccountUpdateParamsIdentityIndividualRelationship,
        AccountUpdateParamsIdentityIndividualScriptAddresses as AccountUpdateParamsIdentityIndividualScriptAddresses,
        AccountUpdateParamsIdentityIndividualScriptAddressesKana as AccountUpdateParamsIdentityIndividualScriptAddressesKana,
        AccountUpdateParamsIdentityIndividualScriptAddressesKanji as AccountUpdateParamsIdentityIndividualScriptAddressesKanji,
        AccountUpdateParamsIdentityIndividualScriptNames as AccountUpdateParamsIdentityIndividualScriptNames,
        AccountUpdateParamsIdentityIndividualScriptNamesKana as AccountUpdateParamsIdentityIndividualScriptNamesKana,
        AccountUpdateParamsIdentityIndividualScriptNamesKanji as AccountUpdateParamsIdentityIndividualScriptNamesKanji,
    )
    from stripe.params.v2.core._claimable_sandbox_create_params import (
        ClaimableSandboxCreateParams as ClaimableSandboxCreateParams,
        ClaimableSandboxCreateParamsPrefill as ClaimableSandboxCreateParamsPrefill,
    )
    from stripe.params.v2.core._claimable_sandbox_retrieve_params import (
        ClaimableSandboxRetrieveParams as ClaimableSandboxRetrieveParams,
    )
    from stripe.params.v2.core._event_destination_create_params import (
        EventDestinationCreateParams as EventDestinationCreateParams,
        EventDestinationCreateParamsAmazonEventbridge as EventDestinationCreateParamsAmazonEventbridge,
        EventDestinationCreateParamsWebhookEndpoint as EventDestinationCreateParamsWebhookEndpoint,
    )
    from stripe.params.v2.core._event_destination_delete_params import (
        EventDestinationDeleteParams as EventDestinationDeleteParams,
    )
    from stripe.params.v2.core._event_destination_disable_params import (
        EventDestinationDisableParams as EventDestinationDisableParams,
    )
    from stripe.params.v2.core._event_destination_enable_params import (
        EventDestinationEnableParams as EventDestinationEnableParams,
    )
    from stripe.params.v2.core._event_destination_list_params import (
        EventDestinationListParams as EventDestinationListParams,
    )
    from stripe.params.v2.core._event_destination_ping_params import (
        EventDestinationPingParams as EventDestinationPingParams,
    )
    from stripe.params.v2.core._event_destination_retrieve_params import (
        EventDestinationRetrieveParams as EventDestinationRetrieveParams,
    )
    from stripe.params.v2.core._event_destination_update_params import (
        EventDestinationUpdateParams as EventDestinationUpdateParams,
        EventDestinationUpdateParamsWebhookEndpoint as EventDestinationUpdateParamsWebhookEndpoint,
    )
    from stripe.params.v2.core._event_list_params import (
        EventListParams as EventListParams,
    )
    from stripe.params.v2.core._event_retrieve_params import (
        EventRetrieveParams as EventRetrieveParams,
    )

# name -> (import_target, is_submodule)
_import_map = {
    "accounts": ("stripe.params.v2.core.accounts", True),
    "vault": ("stripe.params.v2.core.vault", True),
    "AccountCloseParams": (
        "stripe.params.v2.core._account_close_params",
        False,
    ),
    "AccountCreateParams": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfiguration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreator": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilities": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercial": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCeltic": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticChargeCard": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticSpendCard": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBank": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankChargeCard": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankSpendCard": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialLead": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialLeadPrepaidCard": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripe": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripeChargeCard": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripePrepaidCard": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomer": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerAutomaticIndirectTax": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerBilling": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerBillingInvoice": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerBillingInvoiceCustomField": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerBillingInvoiceRendering": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerCapabilities": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTax": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerShipping": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerShippingAddress": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchant": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantBacsDebitPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantBranding": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilities": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAchDebitPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAcssDebitPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAffirmPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAlmaPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAmazonPayPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAuBecsDebitPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesBacsDebitPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesBancontactPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesBlikPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesBoletoPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesCardPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesCartesBancairesPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesCashappPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesEpsPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesFpxPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesGbBankTransferPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesGrabpayPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesIdealPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesJcbPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesJpBankTransferPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesKakaoPayPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesKlarnaPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesKonbiniPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesKrCardPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesLinkPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesMobilepayPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesMultibancoPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesMxBankTransferPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesNaverPayPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesOxxoPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesP24Payments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesPayByBankPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesPaycoPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesPaynowPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesPromptpayPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesRevolutPayPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesSamsungPayPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesSepaBankTransferPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesSepaDebitPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesSwishPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesTwintPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesUsBankTransferPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesZipPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCardPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCardPaymentsDeclineOn": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantStatementDescriptor": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantSupport": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantSupportAddress": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipient": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilities": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccounts": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsLocal": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsWire": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesCards": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesCryptoWallets": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalance": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfers": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationStorer": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationStorerCapabilities": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationStorerCapabilitiesFinancialAddresses": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationStorerCapabilitiesFinancialAddressesBankAccounts": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationStorerCapabilitiesFinancialAddressesCryptoWallets": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationStorerCapabilitiesHoldsCurrencies": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationStorerCapabilitiesHoldsCurrenciesGbp": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationStorerCapabilitiesHoldsCurrenciesUsd": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationStorerCapabilitiesHoldsCurrenciesUsdc": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationStorerCapabilitiesInboundTransfers": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationStorerCapabilitiesInboundTransfersBankAccounts": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationStorerCapabilitiesOutboundPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationStorerCapabilitiesOutboundPaymentsBankAccounts": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationStorerCapabilitiesOutboundPaymentsCards": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationStorerCapabilitiesOutboundPaymentsCryptoWallets": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationStorerCapabilitiesOutboundPaymentsFinancialAccounts": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationStorerCapabilitiesOutboundTransfers": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationStorerCapabilitiesOutboundTransfersBankAccounts": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationStorerCapabilitiesOutboundTransfersCryptoWallets": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationStorerCapabilitiesOutboundTransfersFinancialAccounts": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationStorerRegulatedActivity": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsDefaults": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsDefaultsProfile": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsDefaultsResponsibilities": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentity": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestations": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsDirectorshipDeclaration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsOwnershipDeclaration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsPersonsProvided": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsRepresentativeDeclaration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfService": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceAccount": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreator": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercial": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialAccountHolder": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCeltic": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticApplePay": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCard": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardBankTerms": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardPlatform": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCard": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardBankTerms": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardFinancingDisclosures": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardPlatform": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBank": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankApplePay": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCard": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardBankTerms": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardFinancingDisclosures": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardPlatform": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCard": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardBankTerms": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardFinancingDisclosures": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialGlobalAccountHolder": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLead": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadApplePay": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCard": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCardBankTerms": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCardPlatform": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCryptoStorer": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceStorer": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetails": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsAddress": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsAnnualRevenue": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocuments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyLicense": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerification": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfAddress": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsIdNumber": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsScriptAddresses": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsScriptAddressesKana": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsScriptAddressesKanji": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsScriptNames": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsScriptNamesKana": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsScriptNamesKanji": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividual": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualAdditionalAddress": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualAdditionalName": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualAddress": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualDateOfBirth": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualDocuments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualDocumentsCompanyAuthorization": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualDocumentsPassport": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualDocumentsPrimaryVerification": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualDocumentsSecondaryVerification": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualDocumentsVisa": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualIdNumber": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualRelationship": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualScriptAddresses": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualScriptAddressesKana": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualScriptAddressesKanji": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualScriptNames": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualScriptNamesKana": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualScriptNamesKanji": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountLinkCreateParams": (
        "stripe.params.v2.core._account_link_create_params",
        False,
    ),
    "AccountLinkCreateParamsUseCase": (
        "stripe.params.v2.core._account_link_create_params",
        False,
    ),
    "AccountLinkCreateParamsUseCaseAccountOnboarding": (
        "stripe.params.v2.core._account_link_create_params",
        False,
    ),
    "AccountLinkCreateParamsUseCaseAccountOnboardingCollectionOptions": (
        "stripe.params.v2.core._account_link_create_params",
        False,
    ),
    "AccountLinkCreateParamsUseCaseAccountUpdate": (
        "stripe.params.v2.core._account_link_create_params",
        False,
    ),
    "AccountLinkCreateParamsUseCaseAccountUpdateCollectionOptions": (
        "stripe.params.v2.core._account_link_create_params",
        False,
    ),
    "AccountListParams": ("stripe.params.v2.core._account_list_params", False),
    "AccountRetrieveParams": (
        "stripe.params.v2.core._account_retrieve_params",
        False,
    ),
    "AccountUpdateParams": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfiguration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreator": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilities": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercial": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCeltic": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCelticChargeCard": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCelticSpendCard": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBank": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankChargeCard": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankSpendCard": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialLead": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialLeadPrepaidCard": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialStripe": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialStripeChargeCard": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialStripePrepaidCard": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomer": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerAutomaticIndirectTax": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerBilling": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerBillingInvoice": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerBillingInvoiceCustomField": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerBillingInvoiceRendering": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerCapabilities": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTax": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerShipping": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerShippingAddress": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchant": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantBacsDebitPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantBranding": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilities": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAchDebitPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAcssDebitPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAffirmPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAlmaPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAmazonPayPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAuBecsDebitPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesBacsDebitPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesBancontactPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesBlikPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesBoletoPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesCardPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesCartesBancairesPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesCashappPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesEpsPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesFpxPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesGbBankTransferPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesGrabpayPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesIdealPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesJcbPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesJpBankTransferPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesKakaoPayPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesKlarnaPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesKonbiniPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesKrCardPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesLinkPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesMobilepayPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesMultibancoPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesMxBankTransferPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesNaverPayPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesOxxoPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesP24Payments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesPayByBankPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesPaycoPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesPaynowPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesPromptpayPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesRevolutPayPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesSamsungPayPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesSepaBankTransferPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesSepaDebitPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesSwishPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesTwintPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesUsBankTransferPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesZipPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCardPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCardPaymentsDeclineOn": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantStatementDescriptor": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantSupport": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantSupportAddress": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipient": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilities": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccounts": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsLocal": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsWire": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesCards": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesCryptoWallets": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesStripeBalance": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfers": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationStorer": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationStorerCapabilities": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationStorerCapabilitiesFinancialAddresses": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationStorerCapabilitiesFinancialAddressesBankAccounts": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationStorerCapabilitiesFinancialAddressesCryptoWallets": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationStorerCapabilitiesHoldsCurrencies": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationStorerCapabilitiesHoldsCurrenciesGbp": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationStorerCapabilitiesHoldsCurrenciesUsd": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationStorerCapabilitiesHoldsCurrenciesUsdc": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationStorerCapabilitiesInboundTransfers": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationStorerCapabilitiesInboundTransfersBankAccounts": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationStorerCapabilitiesOutboundPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationStorerCapabilitiesOutboundPaymentsBankAccounts": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationStorerCapabilitiesOutboundPaymentsCards": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationStorerCapabilitiesOutboundPaymentsCryptoWallets": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationStorerCapabilitiesOutboundPaymentsFinancialAccounts": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationStorerCapabilitiesOutboundTransfers": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationStorerCapabilitiesOutboundTransfersBankAccounts": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationStorerCapabilitiesOutboundTransfersCryptoWallets": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationStorerCapabilitiesOutboundTransfersFinancialAccounts": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationStorerRegulatedActivity": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsDefaults": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsDefaultsProfile": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsDefaultsResponsibilities": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentity": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestations": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsDirectorshipDeclaration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsOwnershipDeclaration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsPersonsProvided": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsRepresentativeDeclaration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfService": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceAccount": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreator": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercial": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialAccountHolder": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCeltic": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticApplePay": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCard": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardBankTerms": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardPlatform": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCard": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardBankTerms": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardFinancingDisclosures": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardPlatform": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBank": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankApplePay": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCard": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardBankTerms": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardFinancingDisclosures": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardPlatform": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCard": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardBankTerms": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardFinancingDisclosures": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialGlobalAccountHolder": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLead": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadApplePay": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCard": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCardBankTerms": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCardPlatform": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCryptoStorer": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceStorer": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetails": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsAddress": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsAnnualRevenue": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocuments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyLicense": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsPrimaryVerification": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfAddress": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfRegistration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsIdNumber": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsScriptAddresses": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsScriptAddressesKana": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsScriptAddressesKanji": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsScriptNames": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsScriptNamesKana": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsScriptNamesKanji": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividual": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualAdditionalAddress": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualAdditionalName": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualAddress": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualDateOfBirth": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualDocuments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualDocumentsCompanyAuthorization": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualDocumentsPassport": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualDocumentsPrimaryVerification": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualDocumentsSecondaryVerification": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualDocumentsVisa": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualIdNumber": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualRelationship": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualScriptAddresses": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualScriptAddressesKana": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualScriptAddressesKanji": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualScriptNames": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualScriptNamesKana": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualScriptNamesKanji": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "ClaimableSandboxCreateParams": (
        "stripe.params.v2.core._claimable_sandbox_create_params",
        False,
    ),
    "ClaimableSandboxCreateParamsPrefill": (
        "stripe.params.v2.core._claimable_sandbox_create_params",
        False,
    ),
    "ClaimableSandboxRetrieveParams": (
        "stripe.params.v2.core._claimable_sandbox_retrieve_params",
        False,
    ),
    "EventDestinationCreateParams": (
        "stripe.params.v2.core._event_destination_create_params",
        False,
    ),
    "EventDestinationCreateParamsAmazonEventbridge": (
        "stripe.params.v2.core._event_destination_create_params",
        False,
    ),
    "EventDestinationCreateParamsWebhookEndpoint": (
        "stripe.params.v2.core._event_destination_create_params",
        False,
    ),
    "EventDestinationDeleteParams": (
        "stripe.params.v2.core._event_destination_delete_params",
        False,
    ),
    "EventDestinationDisableParams": (
        "stripe.params.v2.core._event_destination_disable_params",
        False,
    ),
    "EventDestinationEnableParams": (
        "stripe.params.v2.core._event_destination_enable_params",
        False,
    ),
    "EventDestinationListParams": (
        "stripe.params.v2.core._event_destination_list_params",
        False,
    ),
    "EventDestinationPingParams": (
        "stripe.params.v2.core._event_destination_ping_params",
        False,
    ),
    "EventDestinationRetrieveParams": (
        "stripe.params.v2.core._event_destination_retrieve_params",
        False,
    ),
    "EventDestinationUpdateParams": (
        "stripe.params.v2.core._event_destination_update_params",
        False,
    ),
    "EventDestinationUpdateParamsWebhookEndpoint": (
        "stripe.params.v2.core._event_destination_update_params",
        False,
    ),
    "EventListParams": ("stripe.params.v2.core._event_list_params", False),
    "EventRetrieveParams": (
        "stripe.params.v2.core._event_retrieve_params",
        False,
    ),
}
if not TYPE_CHECKING:

    def __getattr__(name):
        try:
            target, is_submodule = _import_map[name]
            module = import_module(target)
            if is_submodule:
                return module

            return getattr(
                module,
                name,
            )
        except KeyError:
            raise AttributeError()



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from typing import List
from typing_extensions import Literal, NotRequired, TypedDict


class AccountEvaluationUpdateParams(TypedDict):
    expand: NotRequired[List[str]]
    """
    Specifies which fields in the response should be expanded.
    """
    type: Literal["registration_succeeded"]
    """
    The type of event to report.
    """



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._request_options import RequestOptions
from typing import Dict, List, Union
from typing_extensions import Literal, NotRequired, TypedDict


class BalanceSettingsModifyParams(RequestOptions):
    expand: NotRequired[List[str]]
    """
    Specifies which fields in the response should be expanded.
    """
    payments: NotRequired["BalanceSettingsModifyParamsPayments"]
    """
    Settings that apply to the [Payments Balance](https://docs.stripe.com/api/balance).
    """


class BalanceSettingsModifyParamsPayments(TypedDict):
    debit_negative_balances: NotRequired[bool]
    """
    A Boolean indicating whether Stripe should try to reclaim negative balances from an attached bank account. For details, see [Understanding Connect Account Balances](https://docs.stripe.com/connect/account-balances).
    """
    payouts: NotRequired["BalanceSettingsModifyParamsPaymentsPayouts"]
    """
    Settings specific to the account's payouts.
    """
    settlement_timing: NotRequired[
        "BalanceSettingsModifyParamsPaymentsSettlementTiming"
    ]
    """
    Settings related to the account's balance settlement timing.
    """


class BalanceSettingsModifyParamsPaymentsPayouts(TypedDict):
    minimum_balance_by_currency: NotRequired[
        "Literal['']|Dict[str, Union[Literal[''], int]]"
    ]
    """
    The minimum balance amount to retain per currency after automatic payouts. Only funds that exceed these amounts are paid out. Learn more about the [minimum balances for automatic payouts](https://docs.stripe.com/payouts/minimum-balances-for-automatic-payouts).
    """
    schedule: NotRequired["BalanceSettingsModifyParamsPaymentsPayoutsSchedule"]
    """
    Details on when funds from charges are available, and when they are paid out to an external account. For details, see our [Setting Bank and Debit Card Payouts](https://docs.stripe.com/connect/bank-transfers#payout-information) documentation.
    """
    statement_descriptor: NotRequired[str]
    """
    The text that appears on the bank account statement for payouts. If not set, this defaults to the platform's bank descriptor as set in the Dashboard.
    """


class BalanceSettingsModifyParamsPaymentsPayoutsSchedule(TypedDict):
    interval: NotRequired[Literal["daily", "manual", "monthly", "weekly"]]
    """
    How frequently available funds are paid out. One of: `daily`, `manual`, `weekly`, or `monthly`. Default is `daily`.
    """
    monthly_payout_days: NotRequired[List[int]]
    """
    The days of the month when available funds are paid out, specified as an array of numbers between 1--31. Payouts nominally scheduled between the 29th and 31st of the month are instead sent on the last day of a shorter month. Required and applicable only if `interval` is `monthly`.
    """
    weekly_payout_days: NotRequired[
        List[Literal["friday", "monday", "thursday", "tuesday", "wednesday"]]
    ]
    """
    The days of the week when available funds are paid out, specified as an array, e.g., [`monday`, `tuesday`]. Required and applicable only if `interval` is `weekly`.
    """


class BalanceSettingsModifyParamsPaymentsSettlementTiming(TypedDict):
    delay_days_override: NotRequired["Literal['']|int"]
    """
    Change `delay_days` for this account, which determines the number of days charge funds are held before becoming available. The maximum value is 31. Passing an empty string to `delay_days_override` will return `delay_days` to the default, which is the lowest available value for the account. [Learn more about controlling delay days](https://docs.stripe.com/connect/manage-payout-schedule).
    """
